@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: libspotter.c,v 1.57 2009/05/13 21:06:44 guru Exp $
+ *	$Id: libspotter.c,v 1.60 2010/01/14 07:15:20 guru Exp $
  *
- *   Copyright (c) 1999-2009 by P. Wessel
+ *   Copyright (c) 1999-2010 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -88,7 +88,8 @@ int spotter_init (char *file, struct EULER **p, int flowline, BOOLEAN finite_in,
 	if (flowline) finite_out = TRUE;	/* Override so we get finite poles for conversion to forward stage poles at the end */
 
 	while (GMT_fgets (buffer, 512, fp) != NULL) { /* Expects lon lat t0 t1 ccw-angle */
-		if (buffer[0] == '#' || buffer[0] == '\n') continue;
+		GMT_chop (buffer);					/* Rid the world of CR/LF */
+		if (buffer[0] == '#' || buffer[0] == '\0') continue;
 
 		if (finite_in) {	/* The minimalist record formats is: lon lat t0 [t1] omega [covar] */
 			nf = sscanf (buffer, "%lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf %lf",
@@ -215,7 +216,8 @@ int spotter_hotspot_init (char *file, struct HOTSPOT **p)
 	e = (struct HOTSPOT *) GMT_memory (VNULL, n_alloc, sizeof (struct HOTSPOT), "libspotter");
 
 	while (GMT_fgets (buffer, 512, fp) != NULL) {
-		if (buffer[0] == '#' || buffer[0] == '\n') continue;
+		GMT_chop (buffer);					/* Rid the world of CR/LF */
+		if (buffer[0] == '#' || buffer[0] == '\0') continue;
 		n = sscanf (buffer, "%lf %lf %s %d %lf %lf %lf %c %c %c %s", &e[i].lon, &e[i].lat, e[i].abbrev, &e[i].id, &e[i].radius, &e[i].t_off, &e[i].t_on, &create, &fit, &plot, e[i].name);
 		if (n == 3) e[i].id = i;	/* Minimal lon, lat, abbrev */
 		if (n >= 10) {
@@ -447,13 +449,8 @@ BOOLEAN must_do_track (GMT_LONG sideA[], GMT_LONG sideB[]) {
 	if (sideA[0] == 0 && sideA[1] == 0) return (TRUE);
 	if (sideB[0] == 0 && sideB[1] == 0) return (TRUE);
 	/* Now check if the two points may cut a corner */
-#ifdef __LP64__
-	dx = labs (sideA[0] - sideB[0]);
-	dy = labs (sideA[1] - sideB[1]);
-#else
-	dx = abs (sideA[0] - sideB[0]);
-	dy = abs (sideA[1] - sideB[1]);
-#endif
+	dx = GMT_abs (sideA[0] - sideB[0]);
+	dy = GMT_abs (sideA[1] - sideB[1]);
 	if (dx && dy) return (TRUE);
 	if (dx == 2 || dy == 2) return (TRUE);	/* Could cut across the box */
 	return (FALSE);
@@ -797,13 +794,8 @@ void spotter_add_rotations (struct EULER a[], GMT_LONG n_a, struct EULER b[], GM
 
 	sign_a = (n_a > 0) ? +1.0 : -1.0;
 	sign_b = (n_b > 0) ? +1.0 : -1.0;
-#ifdef __LP64__
-	n_a = labs (n_a);
-	n_b = labs (n_b);
-#else
-	n_a = abs (n_a);
-	n_b = abs (n_b);
-#endif
+	n_a = GMT_abs (n_a);
+	n_b = GMT_abs (n_b);
 	/* Allocate more than we need, must likely */
 
 	t = (double *) GMT_memory (VNULL, (size_t)(n_a + n_b), sizeof (double), "libspotter");
